(**************************************************************************************)
(*  'tils Lib - Librairie de composants divers                                        *)
(*  Copyright (C) 2003  U. Van Den Hekke                                              *)
(*                                                                                    *)
(*  This library is free software; you can redistribute it and/or                     *)
(*  modify it under the terms of the GNU Lesser General Public                        *)
(*  License as published by the Free Software Foundation; either                      *)
(*  version 2.1 of the License, or (at your option) any later version.                *)
(*                                                                                    *)
(*  This library is distributed in the hope that it will be useful,                   *)
(*  but WITHOUT ANY WARRANTY; without even the implied warranty of                    *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                 *)
(*  Lesser General Public License for more details.                                   *)
(*                                                                                    *)
(*  You should have received a copy of the GNU Lesser General Public                  *)
(*  License along with this library; if not, write to the Free Software               *)
(*  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA         *)
(**************************************************************************************)

unit ConsoleManager;

interface

uses SysUtils, Graphics, Windows;

const

{ Foreground and background color constants }

  Black         = 0;
  Blue          = 1;
  Green         = 2;
  Cyan          = 3;
  Red           = 4;
  Magenta       = 5;
  Brown         = 6;
  LightGray     = 7;

{ Foreground color constants }

  DarkGray      = 8;
  LightBlue     = 9;
  LightGreen    = 10;
  LightCyan     = 11;
  LightRed      = 12;
  LightMagenta  = 13;
  Yelllow       = 14;
  White         = 15;

{ Add-in for blinking }

  Blink         = 128;

var
  TextAttr      : Word;  { Current text atribute }
  NormAttr      : Word;

procedure setConsoleTitle(const Title: string);
function getConsoleTitle: string;

procedure TextColor(Color: Byte);
procedure TextBackground(Color: Byte);
procedure LowVideo;
procedure HighVideo;
procedure NormVideo;

implementation

procedure TextColor(Color: Byte);
begin
  TextAttr := (TextAttr and $FF00) + Color;
  SetConsoleTextAttribute(getStdHandle(STD_OUTPUT_HANDLE), TextAttr);
end;

procedure TextBackground(Color: Byte);
begin
  TextAttr := (TextAttr and $FF) + (Color shl 8);
  SetConsoleTextAttribute(getStdHandle(STD_OUTPUT_HANDLE), TextAttr);
end;

procedure LowVideo;
begin
  asm
    and   TextAttr,0F7H
  end;
  SetConsoleTextAttribute(getStdHandle(STD_OUTPUT_HANDLE), TextAttr);
end;

procedure HighVideo;
begin
  asm
    or    TextAttr,8
  end;
  SetConsoleTextAttribute(getStdHandle(STD_OUTPUT_HANDLE), TextAttr);
end;

procedure NormVideo;
begin
  asm
    mov   ax,NormAttr
    mov   TextAttr,ax
  end;
  SetConsoleTextAttribute(getStdHandle(STD_OUTPUT_HANDLE), TextAttr);
end;

procedure setConsoleTitle(const Title: string);
begin
  Windows.SetConsoleTitle(PChar(Title));
end;

function getConsoleTitle: string;
var P: PChar;
begin
  GetMem(P, 256);
  try
    Windows.getConsoleTitle(P, 256);
    result := StrPas(P);
  finally
    FreeMem(P);
  end;
end;

initialization
  TextColor(LightGray);
  TextBackground(Black);
  NormAttr := TextAttr;

end.
